@@ -5,7 +5,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 use v5.36;
 
-our $VERSION = '0.0401';
+our $VERSION = '0.0402';
 
 use Moo;
 use strictures 2;
@@ -113,7 +113,7 @@ sub _open_port($device, $name) {
 sub _rtmidi_loop ($msg_ch, $midi_ch) {
     my $midi_in = MIDI::RtMidi::FFI::Device->new(type => 'in');
     _open_port($midi_in, ${ $msg_ch->recv });
-    $midi_in->set_callback_decoded(sub { $midi_ch->send([ @_[0, 2] ]) });
+    $midi_in->set_callback_decoded(sub { $midi_ch->send([ @_[0, 2] ]) }); # delta-time, event
     sleep;
 }
 
@@ -124,6 +124,7 @@ sub _filter_and_forward ($self, $dt, $event) {
     for my $filter (@$event_filters) {
         return if $filter->($dt, $event);
     }
+
     $self->send_it($event);
 }
 
@@ -173,7 +174,7 @@ MIDI::RtController - Control your MIDI controller
 
 =head1 VERSION
 
-version 0.0401
+version 0.0402
 
 =head1 SYNOPSIS
 
@@ -196,8 +197,22 @@ version 0.0401
     return 0;
   }
 
-  $rtc->add_filter('filter_tone', $_ => \&filter_tone)
+  # capture specific events:
+  $rtc->add_filter('filter_tone', $_, \&filter_tone)
     for qw(note_on note_off);
+  # Or:
+  $rtc->add_filter('filter_tone', [qw(note_on note_off)], \&filter_tone);
+
+  # capture all events:
+  $rtc->add_filter(
+    'echo',
+    all => sub {
+      my ($dt, $event) = @_;
+      print "dt: $dt, ev: ", join( ', ', @$event ), "\n"
+        unless $event->[0] eq 'clock';
+      return 0;
+    }
+  );
 
   # add other stuff to the $rtc->loop...
 
@@ -260,7 +275,8 @@ Send a MIDI B<event> to the output port.
 
   $rtc->delay_send($delay_time, $event);
 
-Send a MIDI B<event> to the output port when the B<delay_time> expires.
+Send a MIDI B<event> to the output port when the B<delay_time> (in
+seconds) expires.
 
 =head2 run
 
@@ -272,8 +288,13 @@ Run the asynchronous B<loop>!
 
   $rtc->add_filter($name, $event_type, $action);
 
-Add a named filter, defined by the CODE reference B<action>, for an
-B<event_type> like C<note_on> or C<note_off>.
+Add a named filter, defined by the CODE reference B<action> for an
+B<event_type> like C<note_on> or C<note_off>. An ARRAY reference
+of event types like: C<[qw(note_on note_off)]> may also be given.
+
+The special event type C<all> may also be used to refer to any
+controller event (e.g. C<note_on>, C<control_change>,
+C<pitch_wheel_change>, C<CC#>s, etc.).
 
 =head1 THANK YOU
 
